==> chromium-64.0.3282.71.tar.xz: chromium-64.0.3282.71/chrome/browser/signin/account_investigator_factory.cc <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/signin/account_investigator_factory.h"

#include "base/memory/singleton.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/signin/gaia_cookie_manager_service_factory.h"
#include "chrome/browser/signin/signin_manager_factory.h"
#include "components/keyed_service/content/browser_context_dependency_manager.h"
#include "components/pref_registry/pref_registry_syncable.h"
#include "components/prefs/pref_service_factory.h"
#include "components/signin/core/browser/account_investigator.h"
#include "components/signin/core/browser/signin_manager.h"

// static
AccountInvestigatorFactory* AccountInvestigatorFactory::GetInstance() {
  return base::Singleton<AccountInvestigatorFactory>::get();
}

// static
AccountInvestigator* AccountInvestigatorFactory::GetForProfile(
    Profile* profile) {
  return static_cast<AccountInvestigator*>(
      GetInstance()->GetServiceForBrowserContext(profile, true));
}

AccountInvestigatorFactory::AccountInvestigatorFactory()
    : BrowserContextKeyedServiceFactory(
          "AccountInvestigator",
          BrowserContextDependencyManager::GetInstance()) {
  DependsOn(GaiaCookieManagerServiceFactory::GetInstance());
  DependsOn(SigninManagerFactory::GetInstance());
}

AccountInvestigatorFactory::~AccountInvestigatorFactory() {}

KeyedService* AccountInvestigatorFactory::BuildServiceInstanceFor(
    content::BrowserContext* context) const {
  Profile* profile(Profile::FromBrowserContext(context));
  AccountInvestigator* investigator = new AccountInvestigator(
      GaiaCookieManagerServiceFactory::GetForProfile(profile),
      profile->GetPrefs(), SigninManagerFactory::GetForProfile(profile));
  investigator->Initialize();
  return investigator;
}

void AccountInvestigatorFactory::RegisterProfilePrefs(
    user_prefs::PrefRegistrySyncable* registry) {
  AccountInvestigator::RegisterPrefs(registry);
}

bool AccountInvestigatorFactory::ServiceIsCreatedWithBrowserContext() const {
  return true;
}

bool AccountInvestigatorFactory::ServiceIsNULLWhileTesting() const {
  return true;
}

==> chromium_72.0.3626.122.orig.tar.xz: chromium-72.0.3626.122/chrome/browser/signin/account_investigator_factory.cc <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/signin/account_investigator_factory.h"

#include "base/memory/singleton.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/signin/gaia_cookie_manager_service_factory.h"
#include "chrome/browser/signin/identity_manager_factory.h"
#include "components/keyed_service/content/browser_context_dependency_manager.h"
#include "components/pref_registry/pref_registry_syncable.h"
#include "components/prefs/pref_service_factory.h"
#include "components/signin/core/browser/account_investigator.h"
#include "services/identity/public/cpp/identity_manager.h"

// static
AccountInvestigatorFactory* AccountInvestigatorFactory::GetInstance() {
  return base::Singleton<AccountInvestigatorFactory>::get();
}

// static
AccountInvestigator* AccountInvestigatorFactory::GetForProfile(
    Profile* profile) {
  return static_cast<AccountInvestigator*>(
      GetInstance()->GetServiceForBrowserContext(profile, true));
}

AccountInvestigatorFactory::AccountInvestigatorFactory()
    : BrowserContextKeyedServiceFactory(
          "AccountInvestigator",
          BrowserContextDependencyManager::GetInstance()) {
  DependsOn(GaiaCookieManagerServiceFactory::GetInstance());
  DependsOn(IdentityManagerFactory::GetInstance());
}

AccountInvestigatorFactory::~AccountInvestigatorFactory() {}

KeyedService* AccountInvestigatorFactory::BuildServiceInstanceFor(
    content::BrowserContext* context) const {
  Profile* profile(Profile::FromBrowserContext(context));
  AccountInvestigator* investigator = new AccountInvestigator(
      GaiaCookieManagerServiceFactory::GetForProfile(profile),
      profile->GetPrefs(), IdentityManagerFactory::GetForProfile(profile));
  investigator->Initialize();
  return investigator;
}

void AccountInvestigatorFactory::RegisterProfilePrefs(
    user_prefs::PrefRegistrySyncable* registry) {
  AccountInvestigator::RegisterPrefs(registry);
}

bool AccountInvestigatorFactory::ServiceIsCreatedWithBrowserContext() const {
  return true;
}

bool AccountInvestigatorFactory::ServiceIsNULLWhileTesting() const {
  return true;
}
